@@ -14,10 +14,10 @@
 
 
 import asyncio
-from typing import List
+from typing import List, Tuple
 
 
-async def run_command(shell_command: List) -> (int, int, str, str):
+async def run_command(shell_command: List) -> Tuple[int, int, str, str]:
     """ executes a shell_command,
     and returns the stdout and stderr"""
     process = await asyncio.create_subprocess_exec(
